@@ -28,11 +28,11 @@ class PyHole(object):
 
     def _copy(self):
         '''Return a copy of itself for lazy url building'''
-        return self.__class__(  url = copy(self._url), 
-                        path=copy(self._path), 
-                        params=copy(self._params), 
-                        user_agent = copy(self._user_agent), 
-                        timeout = self._timeout, 
+        return self.__class__(url=copy(self._url),
+                        path=copy(self._path),
+                        params=copy(self._params),
+                        user_agent=copy(self._user_agent),
+                        timeout=self._timeout,
                         opener=self._opener,
                         force_slash=self._force_slash,
                 )
@@ -69,8 +69,19 @@ class PyHole(object):
     # Creating URL
     def __makeurl__ (self):
         '''Creates full url from self'''
-        return self._url + ('/' if self._path and self._url[-1] != '/' else '' ) + '/'.join(map(lambda x: urllib2.quote(str(x), '~'), self._path)) + ('' if not self._path and self._url[-1] == '/' else self._trailing_slash) + ('?' + urllib.urlencode(self._params.items()) if self._params else '')
-    
+        url = copy(self._url)
+        if self._path and self._url[-1] != '/':
+            url += '/'
+            
+        url += '/'.join(map(lambda x: urllib2.quote(str(x), '~'), self._path))
+        
+        if not url[-1] == '/':
+            url += self._trailing_slash
+            
+        if self._params:
+            url += '?%s' % urllib.urlencode(self._params)
+        #return self._url + ('/' if self._path and self._url[-1] != '/' else '') + '/'.join(map(lambda x: urllib2.quote(str(x), '~'), self._path)) + ('' if not self._path and self._url[-1] == '/' else self._trailing_slash) + ('?' + urllib.urlencode(self._params.items()) if self._params else '')
+        return url
     # Making HTTP Post or Get
     def _get(self):
         '''Raw fetching GET request through urllib'''
@@ -80,8 +91,21 @@ class PyHole(object):
     def _post(self, data={}):
         '''Raw fetching POST request with data through urllib'''
         return self.__connect__(urllib2.Request(self.__makeurl__(), data=urllib.urlencode(data), headers=self._headers))
+    
+    def _put(self, data={}):
+        '''Raw fetching PUT request with data through urllib'''
+        request = urllib2.Request(self.__makeurl__(), data=urllib.urlencode(data), headers=self._headers)
+        request.get_method = lambda:'PUT'
+        return self.__connect__(request)
 
-    def _wrap_call(self, response, response_wrapper = None):
+    def _delete(self, data={}):
+        '''Raw fetching DELETE request with data through urllib'''
+        request = urllib2.Request(self.__makeurl__(), data=urllib.urlencode(data), headers=self._headers)
+        request.get_method = lambda:'DELETE'
+        return self.__connect__(request)
+
+
+    def _wrap_call(self, response, response_wrapper=None):
         '''Hook for wrapping response with possible conversion wrapper (e.g. yaml.load)'''
         return response_wrapper(response)    
     
@@ -94,6 +118,14 @@ class PyHole(object):
         '''Fetch with POST and process response with wrapper'''
         return self._wrap_call(self._post(data=data), self.get_response_wrapper())
     
+    def put(self, data={}):
+        '''Fetch with PUT and process response with wrapper'''
+        return self._wrap_call(self._put(data=data), self.get_response_wrapper())
+    
+    def delete(self, data={}):
+        '''Fetch with DELETE and process response with wrapper'''
+        return self._wrap_call(self._delete(data=data), self.get_response_wrapper())
+    
     # Connection layer
     def __connect__(self, request):
         '''Raw connecting and response fetching facility'''
@@ -116,4 +148,4 @@ if __name__ == '__main__':
     a = PyHole('http://a')        
     print a.url
     print a._test
-    print a.__test
\ No newline at end of file
+    print a.__test
